/****************************************************************************
** GEditor meta object code from reading C++ file 'gview.h'
**
** Created: Tue May 26 20:53:42 2009
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.8   edited Feb 2 14:59 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "gview.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.8b. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *GEditor::className() const
{
    return "GEditor";
}

QMetaObject *GEditor::metaObj = 0;
static QMetaObjectCleanUp cleanUp_GEditor( "GEditor", &GEditor::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString GEditor::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "GEditor", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString GEditor::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "GEditor", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* GEditor::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QGridView::staticMetaObject();
    static const QUMethod slot_0 = {"blinkTimerTimeout", 0, 0 };
    static const QUMethod slot_1 = {"scrollTimerTimeout", 0, 0 };
    static const QUMethod slot_2 = {"baptizeVisible", 0, 0 };
    static const QUParameter param_slot_3[] = {
	{ "x", &static_QUType_int, 0, QUParameter::In },
	{ "y", &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_3 = {"baptizeVisible", 2, param_slot_3 };
    static const QUMethod slot_4 = {"unflash", 0, 0 };
    static const QUMethod slot_5 = {"docTextChangedLater", 0, 0 };
    static const QUMethod slot_6 = {"ensureCursorVisible", 0, 0 };
    static const QMetaData slot_tbl[] = {
	{ "blinkTimerTimeout()", &slot_0, QMetaData::Private },
	{ "scrollTimerTimeout()", &slot_1, QMetaData::Private },
	{ "baptizeVisible()", &slot_2, QMetaData::Private },
	{ "baptizeVisible(int,int)", &slot_3, QMetaData::Private },
	{ "unflash()", &slot_4, QMetaData::Private },
	{ "docTextChangedLater()", &slot_5, QMetaData::Private },
	{ "ensureCursorVisible()", &slot_6, QMetaData::Private }
    };
    static const QUMethod signal_0 = {"cursorMoved", 0, 0 };
    static const QUMethod signal_1 = {"textChanged", 0, 0 };
    static const QUParameter param_signal_2[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod signal_2 = {"marginClicked", 1, param_signal_2 };
    static const QUParameter param_signal_3[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod signal_3 = {"marginDoubleClicked", 1, param_signal_3 };
    static const QMetaData signal_tbl[] = {
	{ "cursorMoved()", &signal_0, QMetaData::Public },
	{ "textChanged()", &signal_1, QMetaData::Public },
	{ "marginClicked(int)", &signal_2, QMetaData::Public },
	{ "marginDoubleClicked(int)", &signal_3, QMetaData::Public }
    };
    metaObj = QMetaObject::new_metaobject(
	"GEditor", parentObject,
	slot_tbl, 7,
	signal_tbl, 4,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_GEditor.setMetaObject( metaObj );
    return metaObj;
}

void* GEditor::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "GEditor" ) )
	return this;
    return QGridView::qt_cast( clname );
}

// SIGNAL cursorMoved
void GEditor::cursorMoved()
{
    activate_signal( staticMetaObject()->signalOffset() + 0 );
}

// SIGNAL textChanged
void GEditor::textChanged()
{
    activate_signal( staticMetaObject()->signalOffset() + 1 );
}

// SIGNAL marginClicked
void GEditor::marginClicked( int t0 )
{
    activate_signal( staticMetaObject()->signalOffset() + 2, t0 );
}

// SIGNAL marginDoubleClicked
void GEditor::marginDoubleClicked( int t0 )
{
    activate_signal( staticMetaObject()->signalOffset() + 3, t0 );
}

bool GEditor::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: blinkTimerTimeout(); break;
    case 1: scrollTimerTimeout(); break;
    case 2: baptizeVisible(); break;
    case 3: baptizeVisible((int)static_QUType_int.get(_o+1),(int)static_QUType_int.get(_o+2)); break;
    case 4: unflash(); break;
    case 5: docTextChangedLater(); break;
    case 6: ensureCursorVisible(); break;
    default:
	return QGridView::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool GEditor::qt_emit( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->signalOffset() ) {
    case 0: cursorMoved(); break;
    case 1: textChanged(); break;
    case 2: marginClicked((int)static_QUType_int.get(_o+1)); break;
    case 3: marginDoubleClicked((int)static_QUType_int.get(_o+1)); break;
    default:
	return QGridView::qt_emit(_id,_o);
    }
    return TRUE;
}
#ifndef QT_NO_PROPERTIES

bool GEditor::qt_property( int id, int f, QVariant* v)
{
    return QGridView::qt_property( id, f, v);
}

bool GEditor::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
